Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(31)

Unified Diff: chrome/browser/cocoa/extension_installed_bubble_controller.h

Issue 4724005: Add a help bubble pointing to the omnibox when installing an extension with (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/cocoa/extension_installed_bubble_controller.h
diff --git a/chrome/browser/cocoa/extension_installed_bubble_controller.h b/chrome/browser/cocoa/extension_installed_bubble_controller.h
index e5f50a3d9a1d9cad667e8958beee697e0f8f8af8..4633b3fafe46fa96f4064b9d0ffdf89acbcb8ae0 100644
--- a/chrome/browser/cocoa/extension_installed_bubble_controller.h
+++ b/chrome/browser/cocoa/extension_installed_bubble_controller.h
@@ -32,6 +32,7 @@ const int kInnerVerticalMargin = 10;
// We use a different kind of notification for each of these extension types.
typedef enum {
+ kOmniboxKeyword,
Bons 2010/11/11 19:28:57 while you're in here, mind alphabetizing these?
Matt Perry 2010/11/12 07:20:25 Done.
kBrowserAction,
kPageAction,
kGeneric
@@ -68,7 +69,8 @@ typedef enum {
IBOutlet HoverCloseButton* closeButton_;
IBOutlet NSImageView* iconImage_;
IBOutlet NSTextField* extensionInstalledMsg_;
- IBOutlet NSTextField* pageActionInfoMsg_; // Only shown for page actions.
+ // Only shown for page actions and omnibox keywords.
+ IBOutlet NSTextField* extraInfoMsg_;
IBOutlet NSTextField* extensionInstalledInfoMsg_;
}

Powered by Google App Engine
This is Rietveld 408576698